package com.ibm.broker.mqimqe.example;

/*------------------------------------------------------------------------------*/
/* Licensed Materials - Property of IBM                                         */
/*                                                                              */
/*                              MQSeries Everyplace                             */
/*                              ===================                             */
/*                                                                              */
/*                                                                              */
/* Copyright IBM Corp 2001.  All rights reserved.                               */
/*                                                                              */
/* US Government Users Restricted Rights - Use, Duplication or disclosure       */
/* restricted by GSA ADP Schedule Contract with IBM Corp.                       */
/*------------------------------------------------------------------------------*/
import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.application.*;
import examples.administration.simple.*;
import java.io.File;
import com.ibm.broker.mqimqe.wrapper.*;
import java.io.*;

public class SendMessages extends ExampleAdminBase
{
	static String destQueueManager;
	static String destBridgeQueue;
	static String ServerMQe;
	static String InboxQueue;
	static String iniFileName;
public SendMessages(String QMgrName) throws Exception {
	super(QMgrName);
}
/**
 * All work is performed in this method
 * This time, sending messages as MQe-encoded format
 */
public void doIt() throws Exception {
	// Ensure that there are currently no messages on the queue
	flushQ();

	System.out.println("\n\nSending non publish subscribe message to the broker");
	System.out.println("This is constructed using an MQeMsgObject object so all fields will be" + 
		               " passed into the message broker");
	// Send MQe message into the message broker
	nonPubSub_MQe();
	// Read the message returned from the message broker
	readqueueMQe();
	System.out.println("\n\nSending non publish subscribe message to the broker");
	System.out.println("This is constructed using an MQeMbMsgObject so only the fields compatible" +
		               " within the message broker will be sent");
	nonPubSub_Mb();
	// Read the message returned from the message broker
	readqueueMb();

	// Cleanup
	close();
}
public void flushQ() throws Exception {
	MQeMsgObject msgObj = null;
	do {
		try {
			msgObj = myQM.getMessage(ServerMQe, InboxQueue, null, null, 0);
		} catch (Exception e) {
			msgObj = null;
		}
	} while (msgObj != null);
}
public static void main(String args[]) throws Exception {
	// Check that we have the correct number of parameters
	if (args.length == 5) {
		// Set the parameters
		ServerMQe = args[0];
		iniFileName = args[1];
		destQueueManager = args[2];
		destBridgeQueue = args[3];
		InboxQueue = args[4];

		// Create an instance of the class and call the doIt() method
		new SendMessages(ServerMQe).doIt();
	} else {
		System.out.println("The required parameters are:");
		System.out.println("1] MQe queue manager name");
		System.out.println("2] Client configuration .ini file");
		System.out.println("3] MQSeries queue manager name used by the broker");
		System.out.println("4] Bridge queue name");
		System.out.println("5] Queue name to place the returning messages from the message broker");
	}
}
public void nonPubSub_Mb() throws Exception {
	try {
		//System.out.println("Non pub sub - Mb message object");
		MQeMbMsgObject msg = new MQeMbMsgObject();
		msg.putInt(MQeMbConstants.TYPE_OF_MSG, MQeMbConstants.TYPE_MQE);
		msg.setCorrelationId(
			MQe.hexToByte("010000000000000000000000000000000000000000000000"));
		msg.setDestQueueMgr(ServerMQe);
		msg.setDestQueueName(InboxQueue);
		msg.setReplyToQueueManagerName(myQM.getName());
		msg.setReplyToQueueName(MQe.System_Default_Queue_Name);
		msg.setMessageId(
			MQe.hexToByte("414D51204172676F4D51652020202020E636EB3813211200"));
		msg.setExpiry(-1);
		msg.setGroupId(
			MQe.hexToByte("000000000000000000000000000000000000000000000001"));
		msg.setAccountingToken(
			MQe.hexToByte("0000000000000000000000000000000000000000000000000000000000000001"));
		msg.setPersistence(0);
		msg.setMessageType(8);

		// Note that this data is passed as is into the message broker but only one field is 
		// supported.  This differs from the MQeMsgObject which is not easily parsable within 
		// the message broker although passes all avliable fields
		byte[] theData = asciiToByte("This is the payload");
		msg.setData(theData);

		myQM.putMessage(destQueueManager, destBridgeQueue, msg, null, 0);
	} catch (Exception e) {
		e.printStackTrace();
		System.out.println(example + " Failed! " + e);
	}
}
public void nonPubSub_MQe() throws Exception {
	try {
		//System.out.println("Non pub sub - MQe message object");
		MQeMsgObject msg = new MQeMsgObject();
		msg.putInt(MQeMbConstants.TYPE_OF_MSG, MQeMbConstants.TYPE_MQE);
		msg.putArrayOfByte(MQe.Msg_CorrelID, 
			MQe.hexToByte("010000000000000000000000000000000000000000000000"));
		msg.putAscii(MQeMbConstants.MQ_DestQueueMgr, ServerMQe);
		msg.putAscii(MQeMbConstants.MQ_DestQueueName, InboxQueue);
		msg.putAscii(MQe.Msg_ReplyToQMgr, myQM.getName());
		msg.putAscii(MQe.Msg_ReplyToQ, MQe.System_Default_Queue_Name);
		msg.putArrayOfByte(MQe.Msg_MsgID, 
			MQe.hexToByte("414D51204172676F4D51652020202020E636EB3813211200"));
		msg.putArrayOfByte(MQeMbConstants.MQ_GroupId, 
			MQe.hexToByte("000000000000000000000000000000000000000000000000"));
		msg.putArrayOfByte(MQeMbConstants.MQ_AccountingToken, 
			MQe.hexToByte("0100000000000000000000000000000000000000000000000000000000000000"));
		msg.putInt(MQe.Msg_ExpireTime, -1);
		msg.putInt(MQeMbConstants.MQ_Persistence, 0);
		msg.putInt(MQeMbConstants.MQ_MessageType, 8);

		// Note that this data is not easily parsable within the message broker although all 
		// fields provided are passed.  This is unlike the MQeMbMsgObject which only supports 
		// one payload field although is more parsable within the message broker.

		// Data
		byte[] theData = asciiToByte("This is the payload");
		msg.putArrayOfByte(MQeMbConstants.MQ_Data, theData);
		
		// Own Data
		String ownData = "My own tag with some data";
		msg.putAscii("myOwnTag", ownData);

		// Put the message to the bridge queue
		myQM.putMessage(destQueueManager, destBridgeQueue, msg, null, 0);
	} catch (Exception e) {
		e.printStackTrace();
		System.out.println(example + " Failed! " + e);
	}
}
public void readqueueMb() throws Exception {
	try {
		int limit = 10;		// The number of seconds to wait for a message
		System.out.println("Reading message from queue");
		
		MQeMsgObject msgObj = null;
		while ((msgObj == null) && (limit-- > 0)) {
			try {
				msgObj = myQM.getMessage(ServerMQe, InboxQueue, null, null, 0);
			} catch (Exception e) {
				msgObj = null;
				Thread.sleep(1000);
			}
		}
		byte data[] = msgObj.getArrayOfByte(MQeMbConstants.MQ_Data);
		System.out.println("Message:         " + byteToAscii(data));
	} catch (Exception e) {
		System.out.println("The message retrieved did not contain all of the expected fields");
	}
}
public void readqueueMQe() throws Exception {
	try {
		int limit = 10;		// The number of seconds to wait for a message
		System.out.println("Reading message from queue");
		
		MQeMsgObject msgObj = null;
		while ((msgObj == null) && (limit-- > 0)) {
			try {
				msgObj = myQM.getMessage(ServerMQe, InboxQueue, null, null, 0);
			} catch (Exception e) {
				msgObj = null;
				Thread.sleep(1000);
			}
		}
			
		// Extract the data
		byte data[] = msgObj.getArrayOfByte(MQeMbConstants.MQ_Data);
		String ownData = msgObj.getAscii("myOwnTag");
		
		// Display the data
		System.out.println("Message:         " + byteToAscii(data));
		System.out.println("Own message tag: " + ownData);
	} catch (Exception e) {
		System.out.println("The message retrieved did not contain all of the expected fields");
	}
}
/**
 * Over-ride default parameter settings.
 */
public void setParms() {
	startupIni = iniFileName;
}
}