package com.ibm.broker.mqimqe.example;

/*------------------------------------------------------------------------------*/
/* Licensed Materials - Property of IBM                                         */
/*                                                                              */
/*                              MQSeries Everyplace                             */
/*                              ===================                             */
/*                                                                              */
/*                                                                              */
/* Copyright IBM Corp 2001.  All rights reserved.                               */
/*                                                                              */
/* US Government Users Restricted Rights - Use, Duplication or disclosure       */
/* restricted by GSA ADP Schedule Contract with IBM Corp.                       */
/*------------------------------------------------------------------------------*/
import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.application.*;
import examples.administration.simple.*;
import java.io.File;
import com.ibm.broker.mqimqe.wrapper.*;

public class SendPubSubMessages extends ExampleAdminBase
{
	static String destQueueManager;
	static String destBridgeQueue;
	static String ServerMQe;
	static String InboxQueue;
	static String iniFileName;
public SendPubSubMessages(String QMgrName) throws Exception {
	super(QMgrName);
}
public void doIt() throws Exception {
	// Ensure that there are currently no messages on the queue
	flushQ();
	// Send a subscription message
	Subscribe();
	// Sens a publication message
	Publish();
	// Read any messages published for the given subscription
	readqueue();
	// Send an unsubscription message
	UnSubscribe();
	// Cleanup
	close();
}
public void flushQ() throws Exception {
	MQeMsgObject msgObj = null;
	do {
		try {
			msgObj = myQM.getMessage(ServerMQe, InboxQueue, null, null, 0);
		} catch (Exception e) {
			msgObj = null;
		}
	} while (msgObj != null);
}
public static void main(String args[]) throws Exception {
	// Check that we have the correct number of parameters
	if (args.length == 5) {
		// Set the parameters
		ServerMQe = args[0];
		iniFileName = args[1];
		destQueueManager = args[2];
		destBridgeQueue = args[3];
		InboxQueue = args[4];

		// Create an instance of the class and call the doIt() method
		new SendPubSubMessages(ServerMQe).doIt();
	} else {
		System.out.println("The required parameters are:");
		System.out.println("1] MQe queue manager name");
		System.out.println("2] Client configuration .ini file");
		System.out.println("3] MQSeries queue manager name used by the broker:");
		System.out.println("4] Bridge queue name");
		System.out.println("5] Queue name to place the returning messages from the message broker");
	}
}
public void Publish() throws Exception {
	try {
		String topic = "climate";
		byte[] message = asciiToByte("sunny");
		System.out.println("Publishing message to topic '" + topic + "'");

		// Create a message object
		MQeMsgObject msg = new MQeMsgObject();
		// Set the message type to publish
		msg.putInt(MQeMbConstants.TYPE_OF_MSG, MQeMbConstants.TYPE_PUB);
		// Set the topic for the publication message
		msg.putAscii(MQeMbConstants.TOPIC, topic);
		// Insert the payload
		msg.putArrayOfByte(MQeMbConstants.MESSAGE, message);
		// Set the persistence of the message (zero is non-persistent)
		msg.putInt(MQeMbConstants.MQ_Persistence, 0);
		// Specify that the message is not persistant
		msg.putBoolean(MQeMbConstants.RETAINED, false);
		// Put the message to the MQe bridge queue
		myQM.putMessage(destQueueManager, destBridgeQueue, msg, null, 0);
	} catch (Exception e) {
		e.printStackTrace();
		System.out.println(example + " Failed! " + e);
	}
}
public void readqueue() throws Exception {
	try {
		int limit = 10;		// The number of seconds to wait for a message
		System.out.println("Reading message from queue");
		
		MQeMsgObject msgObj = null;
		while ((msgObj == null) && (limit-- > 0)) {
			try {
				msgObj = myQM.getMessage(ServerMQe, InboxQueue, null, null, 0);
			} catch (Exception e) {
				msgObj = null;
				Thread.sleep(1000);
			}
		}
		// Extract the relevant data from the object and display it
		String topic = msgObj.getAscii(MQeMbConstants.TOPIC);
		byte data[] = msgObj.getArrayOfByte(MQeMbConstants.MESSAGE);
		// Display the data
		System.out.println("Topic:  " + topic);
		System.out.println("Message: " + byteToAscii(data));
	} catch (Exception e) {
		System.out.println("No message found");
	}
}
/**
 * Over-ride default parameter settings.
 */
public void setParms() {
	startupIni = iniFileName;
}
public void Subscribe() throws Exception {
	try {
		String[] topics = {"climate", "humidity", "temperature"};
		System.out.println("Subscribing to the topics:");
		for (int numTopics = 0; numTopics < topics.length; numTopics++) {
			System.out.println(topics[numTopics]);
		}
		// Create the message object
		MQeMsgObject msg = new MQeMsgObject();
		// Set the message type to a subscription message
		msg.putInt(MQeMbConstants.TYPE_OF_MSG, MQeMbLaunch.TYPE_SUB);
		// Set the three topics
		msg.putAsciiArray(MQeMbConstants.TOPIC, topics);
		// Set the queue and queue manager to place any messages for this subscription
		msg.putAscii(MQeMbConstants.MQ_DestQueueName, "Inbox");
		msg.putAscii(MQeMbConstants.MQ_DestQueueMgr, "ServerQM1");
		// Put the subscription message to the bridge queue within MQe
		System.out.println("Put message to QM/queue: "+destQueueManager+"/"+destBridgeQueue);
		myQM.putMessage(destQueueManager, destBridgeQueue, msg, null, 0);
	} catch (Exception e) {
		e.printStackTrace();
		System.out.println(example + " Failed! " + e);
	}
}
public void UnSubscribe() throws Exception {
	try {
		String[] topics = {"climate", "humidity", "temperature"};
		System.out.println("un-subscribing from the topics:");
		for (int numTopics = 0; numTopics < topics.length; numTopics++) {
			System.out.println(topics[numTopics]);
		}
		// Create the message object
		MQeMsgObject msg = new MQeMsgObject();
		// Set the message type to an unsubscription message
		msg.putInt(MQeMbConstants.TYPE_OF_MSG, MQeMbLaunch.TYPE_UNSUB);
		// Set the topics that we want to unsubscribe from
		msg.putAsciiArray(MQeMbConstants.TOPIC, topics);
		// Specify the queue and queue manager that we specified to place messages to
		msg.putAscii(MQeMbConstants.MQ_DestQueueName, "Inbox");
		msg.putAscii(MQeMbConstants.MQ_DestQueueMgr, "ServerQM1");
		// Put the unsubscription message to the bridge queue within MQe
		System.out.println("Put message to QM/queue: "+destQueueManager+"/"+destBridgeQueue);
		myQM.putMessage(destQueueManager, destBridgeQueue, msg, null, 0);
	} catch (Exception e) {
		e.printStackTrace();
		System.out.println(example + " Failed! " + e);
	}
}
}